## $Id: applicant.py 10350 2013-06-22 21:39:00Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from zope.interface import implementedBy
from zope.component import getUtility
from waeup.kofa.interfaces import IExtFileStore
from waeup.kofa.applicants.applicant import ApplicantFactory
from waeup.kofa.utils.helpers import attrs_to_fields
from kofacustom.nigeria.applicants.applicant import NigeriaApplicant
from waeup.imostate.applicants.interfaces import(
    ICustomApplicant, ICustomUGApplicantEdit)

@grok.subscribe(ICustomApplicant, grok.IObjectRemovedEvent)
def custom_handle_applicant_removed(applicant, event):
    """If an applicant is removed also pdf files of this applicant are removed.
    """
    file_store = getUtility(IExtFileStore)
    file_store.deleteFileByContext(applicant, attr='extraform.pdf')
    file_store.deleteFileByContext(applicant, attr='refereeform.pdf')
    file_store.deleteFileByContext(applicant, attr='credentials.pdf')
    return

class CustomApplicant(NigeriaApplicant):

    grok.implements(ICustomApplicant, ICustomUGApplicantEdit)
    grok.provides(ICustomApplicant)


# Set all attributes of CustomApplicant required in ICustomApplicant as field
# properties. Doing this, we do not have to set initial attributes
# ourselves and as a bonus we get free validation when an attribute is
# set.
CustomApplicant = attrs_to_fields(CustomApplicant)

class CustomApplicantFactory(ApplicantFactory):
    """A factory for customized applicants.
    """

    def __call__(self, *args, **kw):
        return CustomApplicant()

    def getInterfaces(self):
        return implementedBy(CustomApplicant)
